@@ -1,8 +1,8 @@
+import matplotlib.pyplot as plt
 import periodictable
-import pylab
 
 params = {'figure.figsize': (10,8)}
-pylab.rcParams.update(params)
+plt.rcParams.update(params)
 
 D = [(el.number,el.density,el.symbol)
     for el in periodictable.elements]
@@ -10,8 +10,8 @@ D = [(el.number,el.density,el.symbol)
 bbox = dict(boxstyle="round",lw=1,ec=(0,0,0),fc=(0.85,0.8,0.8))
 for Z,density,sym in D:
     if density is not None:
-        pylab.text(Z,density,sym,bbox=bbox)
-pylab.axis([0,110,0,25])
-pylab.xlabel('Element number')
-pylab.ylabel('Density of element')
-pylab.title('Density for elements')
+        plt.text(Z,density,sym,bbox=bbox)
+plt.axis([0,110,0,25])
+plt.xlabel('Element number')
+plt.ylabel('Density of element')
+plt.title('Density for elements')
