@@ -69,8 +69,6 @@ https://doi.org/10.1007/3-540-29111-3_1
 [5] Arrighi, F.E., Mandel, M., Bergendahl, J. et al. (1970). Buoyant densities
 of DNA of mammals. Biochem Genet 4, 367–376. https://doi.org/10.1007/BF00485753
 """
-from __future__ import division
-
 import warnings
 
 from .formulas import formula as parse_formula
@@ -98,7 +96,7 @@ def isotope_substitution(formula, source, target, portion=1):
     return formula.replace(source, target, portion=portion)
 
 # TODO: allow Molecule to be used as compound in formulas.formula()
-class Molecule(object):
+class Molecule:
     """
     Specify a biomolecule by name, chemical formula, cell volume and charge.
 
@@ -344,6 +342,10 @@ def _set_amino_acid_average(target, codes, name=None):
     molecule = Molecule(name, formula, cell_volume=cell_volume, charge=charge)
     AMINO_ACID_CODES[target] = molecule
 
+# TODO: importing fasta does work, computing the neutron SLD for each molecule.
+# This triggers nsf.init() which defines the neutron data for each isotope.
+# Further, this does not allow private tables for fasta calculations.
+
 # FASTA code table
 def _(code, V, formula, name):
     if formula[-1] == '-':
@@ -531,35 +533,59 @@ def fasta_table():
     rows += [v for k, v in sorted(NUCLEIC_ACID_COMPONENTS.items())]
     rows += [Sequence("beta casein", beta_casein)]
 
-    print("%20s %7s %7s %7s %5s %5s %5s %5s %5s %5s"
+    print("%25s %7s %7s %7s %5s %5s %5s %5s %5s %5s"
           % ("name", "M(H2O)", "M(D2O)", "volume",
              "den", "#el", "xray", "nH2O", "nD2O", "%D2O match"))
     for v in rows:
         protons = sum(num*el.number for el, num in v.natural_formula.atoms.items())
         electrons = protons - v.charge
         Xsld = xray_sld(v.formula, wavelength=elements.Cu.K_alpha)
-        print("%20s %7.1f %7.1f %7.1f %5.2f %5d %5.2f %5.2f %5.2f %5.1f"%(
+        print("%25s %7.1f %7.1f %7.1f %5.2f %5d %5.2f %5.2f %5.2f %5.1f"%(
             v.name, v.mass, v.Dmass, v.cell_volume, v.natural_formula.density,
             electrons, Xsld[0], v.sld, v.Dsld, v.D2Omatch))
 
 beta_casein = "RELEELNVPGEIVESLSSSEESITRINKKIEKFQSEEQQQTEDELQDKIHPFAQTQSLVYPFPGPIPNSLPQNIPPLTQTPVVVPPFLQPEVMGVSKVKEAMAPKHKEMPFPKYPVEPFTESQSLTLTDVENLHLPLPLLQSWMHQPHQPLPPTVMFPPQSVLSLSQSKVLPVPQKAVPYPQRDMPIQAFLLYQEPVLGPVRGPFPIIV"
 
+## Uncomment to show package path on CI infrastructure
+#def doctestpath():
+#    """
+#    Checking import path for doctests::
+#
+#        >>> import periodictable
+#        >>> print(f"Path to imported periodictable in docstr is {periodictable.__file__}")
+#        some path printed here
+#    """
+
 def test():
     from periodictable.constants import avogadro_number
     from .formulas import formula
     elements = default_table()
-    H2O = formula("H2O@1n")
-    D2O = formula("D2O@1n")
+
+    ## Uncomment to show package path on CI infrastructure
+    #import periodictable
+    #print(f"Path to imported periodictable in package is {periodictable.__file__}")
+    #print(fail_test)
 
     # Beta casein results checked against Duncan McGillivray's spreadsheet
     # name        Hmass   Dmass   vol     den   #el   xray  Hsld  Dsld
     # =========== ======= ======= ======= ===== ===== ===== ===== =====
     # beta casein 23561.9 23880.9 30872.9  1.27 12614 11.55  1.68  2.75
+    # ... updated for new mass table [2023-08]
+    #   same      23562.3 23881.2   same   1.27 same         1.68  2.75
+
     seq = Sequence("beta casein", beta_casein)
-    assert abs((seq.mass-H2O.mass) - 23561.9) < 0.1
-    assert abs((seq.Dmass-D2O.mass) - 23880.9) < 0.1
+    density = seq.mass/avogadro_number/seq.cell_volume*1e24
+    # print(seq.formula)
+    # print(seq.mass, seq.Dmass, density, seq.sld, seq.Dsld)
+
+    # Sequence now includes terminators: H[1]-...-OH[1], so adjust the masses
+    # slightly from the spreadsheet values.
+    H2O = formula("H2O@1n")
+    D2O = formula("D2O@1n")
+    assert abs(seq.mass - (23562.3 + H2O.mass)) < 0.1
+    assert abs(seq.Dmass - (23881.2 + D2O.mass)) < 0.1
     assert abs(seq.cell_volume - 30872.9) < 0.1
-    assert abs(seq.mass/avogadro_number/seq.cell_volume*1e24 - 1.267) < 0.01
+    assert abs(density - 1.267) < 0.01
     assert abs(seq.sld - 1.68) < 0.01
     assert abs(seq.Dsld - 2.75) < 0.01
 
@@ -572,3 +598,4 @@ def test():
 
 if __name__ == "__main__":
     fasta_table()
+    #test()
